==> arch-hs-0.12.0.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.12.0.1
visibility:           public
id:                   arch-hs-0.12.0.1-DJcMDLd7qUVChxjfIoB7rw
key:                  arch-hs-0.12.0.1-DJcMDLd7qUVChxjfIoB7rw
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  0e8a3eb6c2bc1d737f8ec164a7ee9655
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.12.0.1-DJcMDLd7qUVChxjfIoB7rw
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1/include
depends:
    Cabal-3.8.1.0 Diff-0.4.1-94wHByfojTDaWJlRbLpnx
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA
    algebraic-graphs-0.7-207BlB30yiU5oWi9NTcp3T
    arch-web-0.3.1-JpXQNp7kHdgKGsvxjh5AJf base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-HwOUBFINqL9Hdg9Zavx6kP
    conduit-extra-1.3.6-Hy5POq4Iq5rCWv9pFG6p4n containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    hackage-db-2.1.3-2NVJvbac0rZC2jmiPk1Bov
    http-client-0.7.18-7J2pWtgV41wCh8tO4e8XTa
    http-client-tls-0.3.6.4-JK4I6xiNtggFn7ElWv8VCk
    megaparsec-9.6.1-Ktt6gNpgKau6jMucGLxb9e
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    neat-interpolation-0.5.1.4-Brge61mgZUzDssxYeI8NA
    optparse-simple-0.1.1.4-DHa8H4aVdj27U3REaghshn
    polysemy-1.9.2.0-LoSZtu0t3ha7XvG4ZRASfn
    prettyprinter-1.7.1-4uqGG0BkfmSGYTtWuK6zNe
    prettyprinter-ansi-terminal-1.1.3-Jo0fwIaQGdwFOTqqRq4dyg
    servant-client-0.20-F4GTmSuIiyXHI5hXvgT7xl
    split-0.2.5-LghWP1sjueiF0Ln6STtUGf
    tar-conduit-0.4.1-8Ed65idS2G3Czbb3lljPyU template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> arch-hs-0.12.0.1-21-x86_64.pkg.tar.zst: usr/share/haskell/register/arch-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.12.0.1
visibility:           public
id:                   arch-hs-0.12.0.1-FwJflV4tkOH9SX7dZQDDFU
key:                  arch-hs-0.12.0.1-FwJflV4tkOH9SX7dZQDDFU
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  58852ebe7364fdebee86846db9544eac
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.12.0.1-FwJflV4tkOH9SX7dZQDDFU
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.4.8/site-local/arch-hs-0.12.0.1/include
depends:
    Cabal-3.8.1.0 Diff-0.4.1-64n982FmXR97jZWel5t29x
    aeson-2.1.2.1-CJUEk8Q0QXZ63rfmeHQCzY
    algebraic-graphs-0.7-IXFFvANDeAJ8tpimuS3UqG
    arch-web-0.3.1-CJxeYZzScmoKEmp4SC362P base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-t97EsPJ1aWGqkQHikR1p8
    conduit-extra-1.3.6-1V7vliRQJ7JLW9QugEAPr2 containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    hackage-db-2.1.3-584BHFjsnFRHUn5yKJgNoF
    http-client-0.7.18-FHhdytn5xYS9XZS4tP326d
    http-client-tls-0.3.6.4-6ViG6xajb6OInvSbADfE1E
    megaparsec-9.6.1-1ybGI5HvUZSBygPC6kgmDH
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd
    microlens-th-0.4.3.17-Vfga0HXPTS6SXD3NuXqZ3
    neat-interpolation-0.5.1.4-AZiHS5XPkWNJgXCp6CSA2S
    optparse-simple-0.1.1.4-5JY6DfQWQ752nCvdqOugxi
    polysemy-1.9.2.0-6ormICrhx9l6bkuTz4F8FF
    prettyprinter-1.7.1-C5HmRCcNKvH3komkkNnKOd
    prettyprinter-ansi-terminal-1.1.3-GrSGSBDwr8kLyFsmestIN8
    servant-client-0.20-4uB9jBIlcFe8j3JeWsvs0x
    split-0.2.5-4oYyCdOwbo5I1Zv7xTuLK
    tar-conduit-0.4.1-3GNJmRkPWJJ2rknEhpDkWj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
